@@ -150,7 +150,7 @@ def get_eq_info():
     return q.get("earthquake", {})
 
 
-class pprint(object):
+class dict_print(object):
     def __init__(self, json_data):
         if isinstance(json_data, dict):
             self.json_str = json.dumps(json_data)
@@ -158,8 +158,8 @@ class pprint(object):
             self.json_str = json_data
         self.uuid = str(uuid.uuid4())
         # This line is missed out in most of the versions of this script across the web, it is essential for this to work interleaved with print statements
-        self._ipython_display_()
-        
+
+
     def _ipython_display_(self):
         display(HTML('<div id="{}" style="height: auto; width:100%;"></div>'.format(self.uuid)))
         display(HTML("""<script>
